module Foo where

f :: Int -> Int
f x = 5

g :: [a] -> a
g = head
